summaryrefslogtreecommitdiffstats
path: root/import/chips/p9/utils
diff options
context:
space:
mode:
authorClaus Michael Olsen <cmolsen@us.ibm.com>2017-11-08 14:35:02 -0600
committerJoshua Hunsberger <jahunsbe@us.ibm.com>2018-02-01 16:15:30 -0600
commitd18a45c96be4669cb8038a8e2379dded287c76dc (patch)
treeef89bef70545ca6e6f6670da51027b8c4df406c0 /import/chips/p9/utils
parent98fe04d0d6524aa02ac5e3132aabcd05dcefe6c5 (diff)
downloadtalos-hcode-d18a45c96be4669cb8038a8e2379dded287c76dc.tar.gz
talos-hcode-d18a45c96be4669cb8038a8e2379dded287c76dc.zip
Override filter ring support for perv_pll_bndy_bucket rings.
Change-Id: If1d4649da6da3c0d9e09ef4169d4181a1dc43bde Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/49438 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: HWSV CI <hwsv-ci+hostboot@us.ibm.com> Tested-by: PPE CI <ppe-ci+hostboot@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Reviewed-by: Joseph J. McGill <jmcgill@us.ibm.com> Reviewed-by: Sumit Kumar <sumit_kumar@in.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com>
Diffstat (limited to 'import/chips/p9/utils')
-rw-r--r--import/chips/p9/utils/imageProcs/p9_ringId.C8
-rw-r--r--import/chips/p9/utils/imageProcs/p9_ringId.H14
2 files changed, 19 insertions, 3 deletions
diff --git a/import/chips/p9/utils/imageProcs/p9_ringId.C b/import/chips/p9/utils/imageProcs/p9_ringId.C
index 90ecaabb..d3e3a795 100644
--- a/import/chips/p9/utils/imageProcs/p9_ringId.C
+++ b/import/chips/p9/utils/imageProcs/p9_ringId.C
@@ -51,11 +51,15 @@ const GenRingIdList RING_ID_LIST_COMMON[] =
{"perv_pll_bndy_bucket_4", 0x0c, 0x01, 0x01, EKB_RING , 0x01030018},
{"perv_pll_bndy_bucket_5", 0x0d, 0x01, 0x01, EKB_RING , 0x01030018},
{"perv_pll_func" , 0x0e, 0x01, 0x01, EKB_RING , 0x01030010},
+ {"perv_pll_bndy_flt_1" , 0x0f, 0x01, 0x01, EKB_NONFLUSH_RING, 0x01030018},
+ {"perv_pll_bndy_flt_2" , 0x10, 0x01, 0x01, EKB_NONFLUSH_RING, 0x01030018},
+ {"perv_pll_bndy_flt_3" , 0x11, 0x01, 0x01, EKB_NONFLUSH_RING, 0x01030018},
+ {"perv_pll_bndy_flt_4" , 0x12, 0x01, 0x01, EKB_NONFLUSH_RING, 0x01030018},
};
const GenRingIdList RING_ID_LIST_INSTANCE[] =
{
- {"perv_repr" , 0x0f, 0x01, 0x01, VPD_RING , 0x01034006},
- {"occ_repr" , 0x10, 0x01, 0x01, VPD_RING , 0x01030806},
+ {"perv_repr" , 0x13, 0x01, 0x01, VPD_RING , 0x01034006},
+ {"occ_repr" , 0x14, 0x01, 0x01, VPD_RING , 0x01030806},
};
const RingVariantOrder RING_VARIANT_ORDER[] = { BASE, RL, NOT_VALID };
};
diff --git a/import/chips/p9/utils/imageProcs/p9_ringId.H b/import/chips/p9/utils/imageProcs/p9_ringId.H
index 56643081..302cd562 100644
--- a/import/chips/p9/utils/imageProcs/p9_ringId.H
+++ b/import/chips/p9/utils/imageProcs/p9_ringId.H
@@ -199,6 +199,10 @@ enum RingOffset
perv_pll_bndy_bucket_4 = 12,
perv_pll_bndy_bucket_5 = 13,
perv_pll_func = 14,
+ perv_pll_bndy_flt_1 = 15,
+ perv_pll_bndy_flt_2 = 16,
+ perv_pll_bndy_flt_3 = 17,
+ perv_pll_bndy_flt_4 = 18,
// Instance Rings
perv_repr = (0 | INSTANCE_RING_MARK),
occ_repr = (1 | INSTANCE_RING_MARK),
@@ -207,7 +211,7 @@ enum RingOffset
static const ChipletData_t g_chipletData =
{
1, // Pervasive Chiplet ID is 1
- 15, // 15 common rings for pervasive chiplet
+ 19, // 19 common rings for pervasive chiplet
2, // 2 instance specific rings for pervasive chiplet
2,
2, // 2 ring variants: BASE, RL
@@ -969,6 +973,10 @@ static const RingProperties_t RING_PROPERTIES[NUM_RING_IDS] =
{ EQ::eq_inex_bucket_3 , "eq_inex_bucket_3" , EQ_TYPE }, // 250
{ EQ::eq_inex_bucket_4 , "eq_inex_bucket_4" , EQ_TYPE }, // 251
{ EC::ec_cmsk , "ec_cmsk" , EC_TYPE }, // 252
+ { PERV::perv_pll_bndy_flt_1 , "perv_pll_bndy_flt_1" , PERV_TYPE }, // 253
+ { PERV::perv_pll_bndy_flt_2 , "perv_pll_bndy_flt_2" , PERV_TYPE }, // 254
+ { PERV::perv_pll_bndy_flt_3 , "perv_pll_bndy_flt_3" , PERV_TYPE }, // 255
+ { PERV::perv_pll_bndy_flt_4 , "perv_pll_bndy_flt_4" , PERV_TYPE }, // 256
};
#endif
@@ -1228,6 +1236,10 @@ static const RingProperties_t RING_PROPERTIES[NUM_RING_IDS] =
{ EQ::eq_inex_bucket_3 , EQ_TYPE }, // 250
{ EQ::eq_inex_bucket_4 , EQ_TYPE }, // 251
{ EC::ec_cmsk , EC_TYPE }, // 252
+ { PERV::perv_pll_bndy_flt_1 , PERV_TYPE }, // 253
+ { PERV::perv_pll_bndy_flt_2 , PERV_TYPE }, // 254
+ { PERV::perv_pll_bndy_flt_3 , PERV_TYPE }, // 255
+ { PERV::perv_pll_bndy_flt_4 , PERV_TYPE }, // 256
};
#endif
OpenPOWER on IntegriCloud